\name{bayesDensity}
\alias{bayesDensity}
\title{
   Summary for the density estimate based on the Bayesian model.
}
\description{
   Compute the conditional (given the number of mixture components) and
   unconditional estimate of the density function based on the values
   sampled using the reversible jumps McMC (McMC average evaluated in a
   grid of values). Give also the values of each sampled density
   evaluated at that grid (returned as the attribute of the resulting
   object). Methods for printing and plotting are also provided.
}
\usage{
bayesDensity(dir = getwd(), stgrid, grid,
    n.grid = 100, skip = 0, standard = TRUE, unstandard = TRUE)
}
\arguments{
   \item{dir}{directory where to search for files (`mixmoment.sim',
     `mweight.sim', mmean.sim', mvariance.sim') with the McMC sample.}
   \item{stgrid}{grid of values at which the sampled standardized
     densities are to be evaluated. If \code{missing}, the grid is
     automatically computed.}
   \item{grid}{grid of values at which the sampled densities are to be
     evaluated. If \code{missing},
     the grid is guessed from the first 20 sampled mixtures as the sequence starting with the minimal
     sampled mixture mean minus 3 standard deviations of the appropriate mixture
     component, ending with the maximal sampled mixture mean plus 3
     standard deviations of the appropriate mixture
     component, of the length given by \code{n.grid}.}
   \item{n.grid}{the length of the grid if \code{grid = NULL}.}
   \item{skip}{number of rows that should be skipped at the beginning of
   each file with the stored sample.}
   \item{standard}{if \code{TRUE} then also standardized (zero mean,
     unit variance) sampled densities are evaluated.}
   \item{unstandard}{of \code{TRUE} then also original (unstandardized)
     sampled densities are evaluated.}
}
\value{
  An object of class \code{bayesDensity} is returned. This object is a
  list and has potentially two components: \code{standard} and
  \code{unstandard}. Each of these two components is a \code{data.frame}
  with as many rows as number of grid points at which the density was
  evaluated and with columns called `grid', `unconditional' and `k = 1',
  \dots, `k = k.max' giving a predictive errr density, either averaged
  over all sampled \eqn{k}{k}s (unconditional) or averaged over a
  psecific number of mixture components.

  Additionally, the object of class \code{bayesDensity} has three
  attributes:
    \item{sample.size}{a vector of length \code{1 + kmax} giving the
      frequency of each \eqn{k}{k} in the sample.}
    \item{moments}{a \code{data.frame} with columns called `intercept'
      and `scale' giving the mean and variance of the sampled mixture at
      each iteration of the McMC.}
    \item{k}{a \code{data.frame} with one column called `k' giving
      number of mixture components at each iteration.}

  There exists methods to print and plot objects of the class \code{bayesDensity}.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{smooth}







\eof
\name{bayessurvreg.help}
\alias{bayessurvreg.help}
\alias{bayessurvreg.design}
\alias{bayessurvreg.priorBeta}
\alias{bayessurvreg.priorb}
\title{
   Helping function for Bayesian survival regression models.
}
\description{
  These functions are not to be called by ordinary users.

  These are just sub-parts of `bayessurvreg' functions to make them more
  readable for the programmer.
}
\usage{
bayessurvreg.design(m, formula, random, data, transform, dtransform)

bayessurvreg.priorBeta(prior.beta, nX, indb, factors,
   n.factors, n.in.factors)

bayessurvreg.priorb(prior.b, nrandom, ncluster, toler.chol)
}
\arguments{
  \item{m, formula, random, data, transform, dtransform}{}
  \item{prior.beta, nX, indb, factors, n.factors, n.in.factors}{}
  \item{prior.b, nrandom, ncluster, toler.chol}{}
}
\value{
  Some lists.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{internal}
\keyword{connection}

\eof
\name{bayessurvreg1}
\alias{bayessurvreg1}
\title{
   A Bayesian survival regression with a flexible error distribution.
}
\description{
  A function to sample from the posterior distribution for a survival
  regression  model
  \deqn{\log(T_{i,l}) = \beta^T x_{i,l} + b_i^T z_{i,l} +
    \varepsilon_{i,l},\quad i=1,\dots,N,\ l=1,\dots,n_i,}{%
    log(T[i,l]) = beta'*x[i,l] + b[i]'*z[i,l] + epsilon[i,l], i=1,...,N,
    l=1,...,n[i],}
  where distribution of \eqn{\varepsilon_{i,l}}{epsilon[i,l]} is specified
  as a normal mixture with unknown number of components and random
  effect \eqn{b_i}{b[i]} is normally distributed.

  See included paper (/inst/doc directory of this library)
  for more detailed description of prior assumptions.
  
  Sampled values are stored on a disk to be further worked out by e.g.
  \code{coda} or \code{boa}.
}
\usage{
bayessurvreg1(
     formula,
     random,
     data = parent.frame(),
     subset,
     na.action = na.fail,
     x = FALSE,
     y = FALSE,                          
     onlyX = FALSE,
     nsimul = list(niter = 10, nthin = 1, nburn = 0, nnoadapt = 0, nwrite = 10),
     prior = list(kmax = 5, k.prior = "poisson", poisson.k = 3,
                  dirichlet.w = 1,
                  mean.mu = NULL, var.mu = NULL,
                  shape.invsig2 = 1.5,
                  shape.hyper.invsig2 = 0.8, rate.hyper.invsig2 = NULL,
                  pi.split = NULL, pi.birth = NULL,
                  Eb0.depend.mix = FALSE),
     prior.beta,
     prior.b,
     prop.revjump,
     init = list(iter = 0, mixture = NULL, beta = NULL, b = NULL, D = NULL,
                 y = NULL, r = NULL, otherp = NULL, u = NULL),
     store = list(y = TRUE, r = TRUE, b = TRUE, u = TRUE,
                  MHb = FALSE, regresres = FALSE),
     dir = getwd(),
     toler.chol = 1e-10,
     toler.qr = 1e-10,
     \dots)
}
\arguments{
  \item{formula}{model formula for the `fixed' part of the model, i.e. the
    part that specifies \eqn{\beta^T x_{i,l}}{beta*x[i,l]}. See
    \code{\link[survival]{survreg}} for further details. Intercept is implicitely
    included in the model by estimation of the error distribution. As a
    consequence \code{-1} in the model formula does not have any effect
    on the model.

    If \code{random} is used then the formula must contain
    an identification of clusters in the form \code{cluster(id)}, where
    \code{id} is a name of the variable that determines clusters, e.g.
    \tabular{c}{
      \code{Surv(time, event)~gender + cluster(id)}.
    }  
  }
  \item{random}{formula for the `random' part of the model, i.e. the
    part that specifies \eqn{b_i^T z_{i,l}}{b[i]'*z[i,l]}. If omitted,
    no random part is included in the model. E.g. to specify the model with a
    random intercept, say \code{random=~1}. All effects mentioned in
    \code{random} should also be mentioned on the right-hand side of
    \code{formula}.

    When some random effects are included the random intercept is added
    by default. It can be removed using e.g. \code{random=~-1 + gender}.
  }
  \item{data}{optional data frame in which to interpret the variables
    occuring in the formulas.}
  \item{subset}{subset of the observations to be used in the fit.}
  \item{na.action}{function to be used to handle any \code{NA}s in the
    data. The user is discouraged to change a default value
    \code{na.fail}.}
  \item{x}{if \code{TRUE} then the \code{X} matrix is returned. This
    matrix contain all columns appearing in both \code{formula} and
    \code{random} parameters.}  
  \item{y}{if \code{TRUE} then the \code{y} matrix (of log-survival
    times) is returned.}
  \item{onlyX}{if TRUE, no McMC is performed. The function returns only
    a design matrix of your model (intercept excluded). It might be
    useful to set up correctly a parameter for a block update of
    \eqn{\beta}{beta} (regression parameters related to the fixed
    effects) and \eqn{\gamma}{gamma} (means of the random effects,
    random intercept excluded) parameters in the model if
    Metropolis-Hastings is to be used instead of default Gibbs.}
  \item{nsimul}{a list giving the number of iterations of the McMC and
    other parameters of the simulation.
    \describe{
      \item{niter}{total number of sampled values after discarding
	thinned ones, burn-up included.}
      \item{nthin}{thinning interval.}
      \item{nburn}{number of sampled values in a burn-up period after
	discarding thinned values. This value should be smaller than
	\code{niter}. If not, \code{nburn} is set to \code{niter - 1}. It can be set to zero.}
      \item{nnoadapt}{applicable if some blocks of parameters are
	updated using an adaptive Metropolis algorithm. This is a number
        of sampled values that are generated using an initial and fixed
	proposal covariance matrix. It should be smaller or equal to
	\code{nburn}. If not, \code{nnoadapt} is set to \code{nburn}.}
      \item{nwrite}{an interval at which sampled values are written to
	files. }
    }
  }    
  \item{prior}{a list that identifies prior hyperparameters and prior
    choices. See accompanying paper for more details.
    Some prior parameters can be guessed by the function itself. If you
    want to do so, set such parameters to \code{NULL}. Set to
    \code{NULL} also the parameters that are not needed in your model.
    \describe{
      \item{kmax}{value of \eqn{k_{max}}{k[max]}, upper limit for the
	number of mixture components. Its high values like 100 will
	usually correspond to \eqn{\infty}{infinity}.}
      \item{k.prior}{a string specifying the prior distribution of
	\eqn{k}{k}, number of mixture components. Valid are either
	``poisson'', ``uniform'', or ``fixed''. When ``fixed'' is given
	then the number of mixture components is not sampled.}
      \item{poisson.k}{prior hyperparameter \eqn{\lambda}{lambda} for
	the number of mixture components $k$ if Poisson prior for this
	parameter is used.}
      \item{dirichlet.w}{prior hyperparameter \eqn{\delta}{delta} for
	the Dirichlet distribution of mixture weights
	\eqn{w_1,\dots,w_k}{w[1],...w[k]}.}
      \item{mean.mu}{prior hyperparameter \eqn{\xi}{xi} for the mean of
	the normal prior for mixture means
	\eqn{\mu_1,\dots,\mu_k}{mu[1],...,mu[k]}.}
      \item{var.mu}{prior hyperparameter \eqn{\kappa}{kappa} for the
	variance of the normal prior for mixture means \eqn{\mu_1,\dots,\mu_k}{mu[1],...,mu[k]}.}
      \item{shape.invsig2}{prior hyperparameter \eqn{\zeta}{zeta} for
	the shape of the inverse-gamma distribution for the mixture
	variances
	\eqn{\sigma_1^2,\dots,\sigma_k^2}{sigma[1]^2,...,sigma[k]^2}.}
      \item{shape.hyper.invsig2}{prior hyperparameter (shape) \eqn{g}{g} for the
        gamma distribution of the parameter \eqn{\eta}{eta}. Remember,
	\eqn{\eta}{eta} is a scale parameter of the inverse-gamma distribution for the mixture
	variances
	\eqn{\sigma_1^2,\dots,\sigma_k^2}{sigma[1]^2,...,sigma[k]^2}.}
      \item{rate.hyper.invsig2}{prior hyperparameter (rate) \eqn{h}{h} for the
        gamma distribution of the parameter \eqn{\eta}{eta}. Remember,
	\eqn{\eta}{eta} is a scale parameter of the inverse-gamma distribution for the mixture
	variances
	\eqn{\sigma_1^2,\dots,\sigma_k^2}{sigma[1]^2,...,sigma[k]^2}.}
      \item{pi.split}{probabilities of a split move within the
	reversible jump McMC. It must be a vector of length equal to
	\code{kmax} with the first component equal to 1 and the last
	component equal to 0. If \code{NULL} 2nd to (k-1)th components
	are set to 0.5.}
      \item{pi.birth}{probabilities of a birth move within the
	reversible jump McMC. It must be a vector of length equal to
	\code{kmax} with the first component equal to 1 and the last
	component equal to 0. If \code{NULL} 2nd to (k-1)th components
	are set to 0.5.}
      \item{Eb0.depend.mix}{this will normally be \code{FALSE}. Setting
	this option to \code{TRUE} served for some experiments during
	the development of this function. In principle, when this is set
	to \code{TRUE} and the random intercept is included in the model
	then it is assumed that the mean of the random intercept is not
	zero but \eqn{\sum_{j=1}^k w_j\mu_j}{sum[j=1][k] w[j]*mu[j]},
	i.e. the mean of the random intercept depends on
	mixture. However, this did not werk too well.	
      }	
    }
  }
  \item{prior.beta}{a list defining the blocks of \eqn{\beta}{beta}
    parameters (both fixed effects and means of random effects, except
    the random intercept) that are to be updated together (in a block),
    a description of how they are updated and a specification of priors.
    The list is assumed to have the following components.
    \describe{
    \item{mean.prior}{a vector specifying a prior mean for each
      \eqn{\beta}{beta} parameter in the model.}
    \item{var.prior}{a vector specifying a prior variance for each
      \eqn{\beta}{beta} parameter. It is recommended to run the function
      \code{bayesAFT} first with its argument \code{onlyX} set to
      \code{TRUE} to find out how the \eqn{\beta}{beta}s are
      sorted. They must correspond to a design matrix X.}
    \item{blocks}{a list with the following components.
      \describe{
        \item{ind.block}{a list with vectors with indeces of columns of
         the design matrix X defining the effect of \eqn{\beta}{beta}s in the
         block. If not specified, all \eqn{\beta}{beta} parameters
	 corresponding to fixed effects are updated in one block and
	 remaining \eqn{\beta}{beta} parameters (means of random
	 effects) in the second block using the Gibbs move.}
       \item{cov.prop}{a list with vectors with a lower triangle of the covariance
         matrix which is used in the normal proposal (use a command
         \code{\link{lower.tri}} with \code{diag = TRUE} to get a lower
	 triangle from a matrix) when one of the Metopolis-like
	 algorithms is used for
         a given block. This matrix is used at each iteration if the given
         block is updated using a standard random-walk Metropolis-Hastings step. If the
         block is updated using an adaptive Metropolis step this matrix is
         used only at start. If not specified and Metropolis-like
	 algorith is required a diagonal matrix with prior
         variances for corresponding \eqn{\beta}{beta} on a diagonal is
         used. It is set to a vector of zeros of appropriate length when the Gibbs move is required
	 for a given block.}
      }
    }
    \item{type.upd}{a character vector specifying the type of the update
      that will be used for each block. Valid are substrings of
      either "gibbs" or "adaptive.metropolis" or "random.walk.metropolis".
      Default is "gibbs" for all blocks.}
    \item{mean.sampled}{a vector of means of up to now sampled
      values. This component is useful when the adaptive Metropolis
      algorithm is used and we do not start from the beginning
      (e.g. already several iterations of McMC have already been
      performed). Otherwise, this component does not have to be filled.}
    \item{eps.AM}{a vector with \eqn{\epsilon}{epsilon} from the
      adaptive Metropolis algorithm for each block.}
    \item{sd.AM}{a vector specifying \eqn{s_d, d = 1,\dots, D}{s[d], d =
      1, ..., D} numbers from the
      adaptive Metropolis algorithm for each dimension. This vector must
      be of length equal at least to the length of the longest
      block. Defaults values are \eqn{\frac{1}{d}2.4^2}{(1/d)*2.4^2}
      where \eqn{d}{d} denotes a length of the block.}
    \item{weight.unif}{a vector specifying the weight of the uniform
      component in the proposal for each block. If not specified, it is
      equal to 0.5 for all parameters.}
    \item{half.range.unif}{a vector of same length as the number of
      columns in the design matrix X specifying the half range of the
      uniform component of the proposal.}     
    }
  }
  \item{prior.b}{a list defining the way in which the random effects are
    to be updated and the specification of priors for random effects
    related parameters. The list is assumed to have following components.
    \describe{
    \item{prior.D}{a string defining the prior distribution for the
      covariance matrix of random effects \eqn{D}{D}. It can be either
      ``inv.wishart'' or ``sduniform''.
      \describe{
      \item{inv.wishart}{in that case is assumed that the prior distribution
      of the matrix \eqn{D}{D} is Inverse-Wishart with degrees of freedom
      equal to \eqn{\tau}{tau} and a scale matrix equal to
      \eqn{S}{S}. When \eqn{D}{D} is a matrix \eqn{q\times q}{q x q} a
      prior expectation of \eqn{D}{D} is equal to
      \eqn{(\tau - q - 1)^{-1}S}{(1/(tau - q - 1))S} if
      \eqn{\tau > q + 1}{tau > q + 1}. For
      \eqn{q - 1 < \tau \leq q + 1}{q - 1 < tau <= q + 1} a prior
      expectation is not finite.	
      Degrees of freedom parameter \eqn{\tau}{tau} does not have to be an
      integer. It has to only satisfy a condition
      \eqn{\tau > q - 1}{tau > q - 1}. \code{prior.b$df.D} gives a prior
      degrees of freedom parameter \eqn{\tau}{tau} and
      \code{prior.b$scale.D} determines the scale matrix \eqn{D}{D}.
      This is also the default choice.
      }
      \item{sduniform}{this can be used only when the random effect is
	univariate. Then the matrix \eqn{D}{D} is just a scalar and the
	prior of \eqn{\sqrt{D}}{sqrt(D)} (standard deviation of the
	univariate random effect) is assumed to be uniform on interval
	\eqn{(0, S)}{(0, S)}. The upper limit \eqn{S}{S} is given by \code{prior.b$scale.D}.
      }	
      }
    }
    \item{df.D}{degrees of freedom parameter \eqn{\tau}{tau} in the case
      that the prior of the matrix \eqn{D}{D} is inverse-Wishart.
    }
    \item{scale.D}{a lower triangle of the scale matrix \eqn{S}{S} in
      the case that the prior of the matrix \eqn{D}{D} is
      inverse-Wishart or the upper limit \eqn{S}{S} of the uniform distribution in
      the case that \eqn{\sqrt{D} \sim \mbox{Unif}(0, S)}{sqrt(D) ~
	Unif(0, S)}.}
    \item{type.upd}{a character vector specifying the type of the
      update. Valid are substrings of either "random.walk.metropolis" or
      "gibbs". Default is "gibbs". In contrast to \eqn{\beta}{beta}
      parameters, all random effects are updated using the same type of
      the move. If "random.walk.metropolis" is used, random effects may
      be divided into blocks in which they are updated. With "gibbs",
      there is only one block defined for all random effects.
      which are updated in one step using its full conditional distribution.}
    \item{blocks}{a list with the following components. This is set to
      NULL if \code{type.upd = "gibbs"}.      
      \describe{
         \item{ind.block}{a list with vectors with indeces of random
	   effects defining the block. Random intercept has always an
	   index 1, remaining random effects have subsequent indeces
	   according to their appearance in the design matrix X.}
         \item{cov.prop}{a list with vectors with a lower triangle of the covariance
           matrix which is used in the normal proposal (use a command
           \code{\link{lower.tri}} with \code{diag = TRUE} to get a lower triangle from a matrix) for
           a given block when
           \tabular{c}{
	     \code{type.upd = "random.walk.metropolis"}. 
	   }  
	 }      	
      }
    }	 
    \item{weight.unif}{a vector specifying the weight of the uniform
      component in the proposal for each block when
      \tabular{c}{
	\code{type.upd = "random.walk.metropolis"}. 
      }
      If not specified, it is
      equal to 0.5 for all parameters. It is set to NULL if \code{type.upd = "gibbs"}.} 
    \item{half.range.unif}{a vector of same length as the number of
      random effects specifying the half range of the uniform component
      of the proposal when \code{type.upd = "random.walk.metropolis"}.
      It is set to NULL if \code{type.upd = "gibbs"}.}       
  }
  }
  \item{prop.revjump}{a list of values defining in which way the
    reversible jumps will be performed. 
    \describe{
      \item{algorithm}{a string defining the algorithm used to generate
	canonical proposal vectors
	\eqn{u = (u_{3k+1},\dots, u_{3k_{max}})'}{u = (u[3k+1], ..., u[3kmax])}
	where \eqn{u_{3k+1}, u_{3k+2}, u_{3k+3}}{u[3k+1], u[3k+2], u[3k+3]}
	are directly used when a jump to a space of higher dimension is
	proposed. These canonical proposal vectors are further
	transformed to give desired parameters (mixture component's weight, mean and
	variance). 
	Valid values of \code{prop.revjump$algorithm} are substrings of
	"basic", "independent.av", "correlated.av". \code{"basic"} means
	that both components of vectors \eqn{u}{u} and vectors
	\eqn{u}{u} in time are generated independently from a standard
	uniform distribution. This corresponds to a basic reversible
	jumps McMC algorithm of Green (1995). Other two methods
	implement an auxiliary variable method of Brooks et
	al. (2003). The first one an independent auxiliary variable
	method where vectors \eqn{u}{u} may be correlated in time
	however their components are independent and the second one the
	correlated auxiliary method where vectors \eqn{u}{u} are
	correlated in time and also their components may be
	correlated. In both cases components of vectors \eqn{u}{u}
	follow marginally a standard uniform distribution. A moody ring
	method of Brooks et al. (2003) is used to generate \eqn{u}{u} vectors.
      }
      \item{moody.ring}{parameters for the moody ring when
	\code{algorithm} is either "independent.av" or
	"correlated.av". This is a two component vector with both
	components taking values between 0 and 0.5 defining the strength
        of a correlation in time and between the components of
	\eqn{u}{u} vectors. This vector is ignored when \code{algorithm
	  = "basic"}. The first component of this vector determines
	dependence between \eqn{u}{u} vectors in time
	(\eqn{\varepsilon}{epsilon} in Brooks et al. (2003)), the second
        component determines dependence between components of \eqn{u}{u}
	vectors (\eqn{\delta}{delta} in Brooks et al. (2003)). The
	second compoenent is ignored when \code{algorithm = "independent.av"}.
        Note that both \eqn{\varepsilon}{epsilon} and
	\eqn{\delta}{delta} do not have a meaning of correlation. They
	determine a range of additional uniform distributions. So that
	their values equal to \eqn{0}{0} mean perfect correlation and
	their values equal to \eqn{0.5}{0.5} mean
	independence. I.e. "correlated.av" with \eqn{\delta = 0.5}{delta
	= 0.5} is same as "independent.av" and "correlated.av" with
        \eqn{\delta = 0.5, \varepsilon = 0.5}{delta = 0.5, epsilon =
        0.5} is same as "basic".}
      \item{transform.split.combine}{a description of how the canonical
	variables \eqn{u}{u} are to be transformed to give new values of
        mixture component's weight, mean and variance when a split move
	is proposed. Possible values are substrings of
	"richardson.green", "brooks" and "identity". In all cases, the
	\eqn{(0, 1)}{(0, 1)} canonical variables \eqn{u}{u} are transformed 
	to \eqn{(0, 1)}{(0, 1)} variates \eqn{v}{v} that are than used
        to compute new values of mixture component's weight, mean and
	variance using a method of moments matching described in
	Richardson and Green (1997). When "identity", no further
	transformation is performed, when "richardson.green", \eqn{u}{u}
        vectors are transformed such that the components of resulting \eqn{v}{v}
	vectors follow independently beta distributions with parameters
	given further by \code{p = prop.revjump$transform.split.combine.parms}
	such that in the triplet of v's used in a particular split move,
        \eqn{v_1 \sim beta(p_1, p_2), v_2 \sim beta(p_3, p_4), v_3 \sim beta(p_5, p_6)}{ %
          v[1] ~ beta(p[1], p[2]), v[2] ~ beta(p[3], p[4]), v[3] ~ beta(p[5], p[6])}.
        When "brooks" \eqn{v_2}{v[2]} is further transformed by
	\eqn{|2v_2 - 1|}{|2*v[2] - 1|}. Default values of
	\tabular{c}{
	\code{prop.revjump$transform.split.combine$parms} 
	}
	is \code{c(2, 2, 2, 2, 1, 1)}.}
      \item{transform.split.combine.parms}{see above.}
      \item{transform.birth.death}{a description of how the canonical
	variables \eqn{u}{u} are to be transformed to give new values of
        mixture component's weight, mean and variance when a birth move
	is proposed. At this moment only one value is possible:
	"richardson.green" implementing the proposal as in Richardson
	and Green (1997).}
    }
  }      
  \item{init}{a list of the initial values to start the McMC. Set to
    \code{NULL} such parameters that you want the program should itself sample
    for you or parameters that are not needed in your model.
    \describe{
      \item{iter}{index of the iteration to which initial values
	correspond, usually zero.}
      \item{mixture}{initial mixture for the error random variable
	\eqn{\varepsilon}{epsilon}. It must a vector of length \code{1 +
        3*kmax}, where \code{mixture[1]} gives initial number of mixture
        of components \eqn{k}{k},
        \code{mixture[2:(k+1)]} gives initial mixture weights,
        \code{mixture[(2+kmax):(2+kmax+k-1)]} gives initial mixture means, 
        \code{mixture[(2+2*kmax):(2+2*kmax+k-1)]} gives initial mixture
	variances. Remaining components of this vector are ignored.}
      \item{beta}{initial values of regression parameters in the same
	order as columns of the design matrix \code{X}. Call the
	function \code{bayessurvreg1} with \code{onlyX = TRUE} to see
	how the columns are sorted. Remember, \code{beta} in this
	function contains both fixed effects \eqn{\beta}{beta} and
	means of random effect \eqn{\gamma}{gamma} in the notation of
	the accompanying paper except the mean of
	the random intercept which is always zero.}
      \item{b}{initial values of random effects \eqn{b_i}{b[i]} for each
        cluster. This must a matrix of size \eqn{q \times N}{q x N} or a
	vector of length \eqn{q*N}{q*N},
	where \eqn{q}{q} is a number of random effects and \eqn{N}{N}
	number of clusters, one column per cluster.}
      \item{D}{initial value for the covariance matrix of random effects
        \eqn{D}{D}. Only its lower triangle must be given in a
	vector, e.g. \code{c(d[1,1], d[2,1], d[3,1], d[2,2], d[3,2],
          d[3,3])} for a matrix \eqn{3 \times 3}{3 x 3}.}
      \item{y}{initial values of true log-event times. This must be a
	vector of length \eqn{\sum_{i=1}^N n_i}{sum[i=1][N] n[i]}.}
      \item{r}{initial values of component labels
	\eqn{r_{i,l}}{r_{i,l}}. This must be a vector of length
	\eqn{\sum_{i=1}^N n_i}{sum[i=1][N] n[i]}.}
      \item{otherp}{initial values for other parameters. At this moment,
        only a value of the parameter \eqn{\eta}{eta} is given here.}
      \item{u}{initial canonical proposal vector of length
	\eqn{3k_{max}}{3*kmax}. When initial number of compoents
	given by \code{init$mixture[1]} is \eqn{k}{k}, effectively only
	last \eqn{3k_{max} - 3*k}{3*kmax - 3*k} components of the
        initial \eqn{u}{u} vector are used. Further, when
	\code{prop.revjump$algorithm = "correlated.av"}, the first
	component of \code{init$u} (\code{init$u[1]}) contains an
	initial mood parameter (\eqn{C_0}{c[0]} in Brooks et al. (2003))
        for the moody ring.}
    }      
  }
  \item{store}{a list that defines which sampled values besides
    regression parameters \eqn{\beta}{beta}, means of random effects
    \eqn{\gamma}{gamma} (both stored in a file called \code{beta.sim}),
    a covariance matrix of random effects \eqn{D}{D} (stored
    in a file \code{D.sim}),
    the mixture (stored in file \code{mixmoment.sim, mweight.sim,
      mmean.sim, mvariance.sim}),
    values of other parameters - \eqn{\eta}{eta} (stored in a file \code{otherp.sim}),
    values of log-likelihoods (stored in a file \code{loglik.sim}),
    information concerning the performance of the reversible jump McMC
    and acceptance of regression parameters (stored in a file \code{MHinfo.sim}),
    iteration indeces (stored in a file \code{iteration.sim})
    are to be stored. The list \code{store} has the following
    components.
    \describe{
      \item{y}{if \code{TRUE} sampled true log-event times are  stored.}
      \item{r}{if \code{TRUE} sampled component labels are stored.}
      \item{b}{if \code{TRUE} sampled values of random effects
	\eqn{b_i}{b[i]} are stored.}
      \item{u}{if \code{TRUE} sampled values of canonical proposal
	vectors for the reversible jump McMC are stored.}
      \item{MHb}{if \code{TRUE} information concerning the performance
	of the Metropolis-Hastings algorithm for the update of random
	effects (if used instead of a dafault Gibbs) is stored.}
      \item{regresres}{if \code{TRUE} sampled values of regression
	residuals at each iteration are stored. The regression residual
	is defined as \eqn{res_{i,l} = \log(t_{i,l}) - \beta^T x_{i,l} -
	b_i^T z_{i,l}}{res[i,l] = log(t[i,l]) - beta'*x[i,l] - b[i]'*z[i,l]}.}
  }
  In the case that either \code{store$y}, or \code{store$r}, or
  \code{store$b}, or \code{store$u} are \code{FALSE}, only the last
  values of either \code{y}, or \code{r}, or \code{b}, or \code{u}
  at the time of writting of remaining quantities are stored in
  appropriate files (without headers) to be possibly used by
  \code{\link{bayessurvreg1.files2init}} function.  
  }
  \item{dir}{a string that specifies a directory where all sampled
    values are to be stored.}
  \item{toler.chol}{tolerance for the Cholesky decomposition.}
  \item{toler.qr}{tolerance for the QR decomposition.}
  \item{\dots}{who knows?}
}
\value{
  A list of class \code{bayessurvreg} containing an information
  concerning the initial values and prior choices.
}
\section{Files created}{  
  Additionally, the following files with sampled values
  are stored in a directory specified by \code{dir} parameter of this
  function (some of them are created only on request, see \code{store}
  parameter of this function).
  \describe{
    \item{iteration.sim}{one columns labeled \code{iteration} with
      indeces of McMC iterations to which the stored sampled values correspond.}
    \item{loglik.sim}{two columns labeled \code{loglik} and
      \code{randomloglik}.
      \deqn{\mbox{\code{loglik}} = \sum_{i=1}^{N}\sum_{l=1}^{n_i}
	\log\Bigl(\sum_{j=1}^k w_j \varphi_j(y_{i,l} - \beta^T x_{i,l} - b_i^T
	z_{i,l})\Bigr),}{%
        \code{loglik} = sum[i=1][N]sum[l=1][n[i]] log(sum[j=1][k]
	w[j]*phi[j](y[i,l] - beta'*x[i,l] - b[i]*z[i,l])),}
      where \eqn{\varphi_j}{phi[j]} is a density of
      \eqn{N(\mu_j, \sigma^2_j)}{N(mu[j], sigma[j]^2)},
      \eqn{y_{i,l}}{y[i,l]} denotes (sampled) \emph{(i,l)}th true
      log-event time,
      \eqn{b_i}{b[i]} sampled value of the random effect vector for the
      \emph{i}th cluster,
      \eqn{\beta}{beta} sampled value of the regression parameter
      \eqn{\beta}{beta} and
      \eqn{k, w_j, \mu_j, \sigma_j^2, j = 1,\dots,k}{k, w[j], mu[j], sigma[j]^2, j =
	1,\dots, k} sampled mixture at each iteration.

      \deqn{\mbox{\code{randomloglik}} =
	\sum_{i=1}^{N}\log\Bigl(g(b_i)\Bigr),}{%
	\code{randomloglik} = sum[i=1][N] log(g(b[i])),}
      where \eqn{g}{g} denotes a density of
      (multivariate) normal distribution
      \eqn{N(\gamma, D),}{N(gamma, D),} where
      \eqn{\gamma}{gamma} is a sampled value of the mean of random
      effect vector and \eqn{D}{D} is a sampled value of the covariance
      matrix of the random effects at each iteration.      
    }
    \item{mixmoment.sim}{three columns labeled \code{k}, \code{Intercept} and
      \code{Scale}. These are the number of mixture components, mean and
      standard deviation of the sampled error distribution (mixture) at
      each iteration.}
    \item{mweight.sim}{each row contains mixture weights
      \eqn{w_1,\dots,w_k}{w[1],...,w[k]}
      at each iteration. From the header of this file, maximal number of mixture
      components specified in the prior can be derived.}
    \item{mmean.sim}{each row contains mixture means
      \eqn{\mu_1,\dots,\mu_k}{mu[1],...,mu[k]}
      at each iteration. From the header of this file, maximal number of mixture
      components specified in the prior can be derived.}
    \item{mvariance.sim}{each row contains mixture variances
      \eqn{\sigma^2_1,\dots,\sigma^2_k}{sigma2[1],...,sigma2[k]} at each
      iteration. From the header of this file, maximal number of mixture
      components specified in the prior can be derived.}    
    \item{beta.sim}{columns labeled according to name of the design
      matrix. These are sampled values of regression parameters
      \eqn{\beta}{beta} and means of random effects \eqn{\gamma}{gamma}
      (except the mean of the random intercept which is zero).}
    \item{b.sim}{columns labeled \code{nameb[1].id[1], \dots,
	nameb[q].id[1], \dots, nameb[1].id[N], \dots, nameb[q].id[N]},
      where \code{q} is a dimension of the random effect vector
      \eqn{b_i}{b[i]} and \code{N}{N} number of clusters. \code{nameb}
      is replaced by appropriate column name from the design matrix and
      \code{id} is replaced by identificator of the clusters. This gives
      sampled values of the random effects for each cluster.}
    \item{D.sim}{columns labeled \code{det, D.s.t, s = 1,\dots, q, t =
	s,\dots,q}, where \code{q} is dimension of the random effect
      vector \eqn{b_i}{b[i]}. Column \code{det} gives a determinant of
      the covariance matrix \eqn{D}{D} of the random effects at each
      iteration, remaining columns give a lower triangle of this matrix
      at each iteration.}
    \item{Y.sim}{columns labeled \code{Y[m]} where \code{m} goes from 1
      to \eqn{\sum_{i=1}^{N}n_i}{sum[i=1][N]n_i}. This gives sampled
      log-event times for each observation in the dataset at each
      iteration.}
    \item{r.sim}{columns labeled \code{r[m]} where \code{m} goes from 1
      to \eqn{\sum_{i=1}^{N}n_i}{sum[i=1][N]n_i}. This gives sampled
      mixture labels for each observation in the dataset at each iteration.}
    \item{otherp.sim}{Currently only one column labeled \code{eta} that
      gives sampled values of the hyperparameter \eqn{\eta}{eta}.}
    \item{MHinfo.sim}{this gives the information concerning the
      performance of reversible jump algorithm and a sampler of
      regression parameters \eqn{\beta}{beta} and means of random
      effects \eqn{\gamma}{gamma}. It has columns
      \describe{
        \item{\code{accept.spl.comb}}{relative frequency of accepted
	  split-combine moves up to that iteration.}
	\item{\code{split}}{relative frequency of proposed split moves
	  up to that iteration.}
	\item{\code{accept.birth.death}}{relative frequency of accepted
	  birth-death moves up to that iteration.}
	\item{\code{birth}}{relative frequency of proposed birth moves
	  up to that iteration.}
	\item{\code{beta.block.m}}{with \code{m} going from 1 to number
	  of defined blocks of beta parameters. This gives a relative
	  frequency of accepted proposals for each block up to that
	  iteration. When Gibbs move is used, these should be columns of
	  ones.}
      }	
    }
    \item{MHbinfo.sim}{this gives the information concerning the
      performance of a sampler for random effects (relative frequency of
      accepted values for each cluster and each block of random effects
      updated together). When Gibbs move is used only ones are seen in
      this file.}
    \item{u.sim}{Sampled values of canonical proposal variables for
      reversible jump algorithm are stored here. This file is useful
      only when trying to restart the simulation from some specific point.}
    \item{regresres.sim}{columns labeled \code{res[m]} where \code{m} goes from 1
      to \eqn{\sum_{i=1}^{N}n_i}{sum[i=1][N]n_i.} This stores so called
      regression residuals for each observation at each iteration. This
      residual is defined as
      \deqn{res_{i,l} = y_{i,l} - \beta^T x_{i,l} - b_i z_{i,l},\qquad
	i=1\dots,N,\quad l=1,\dots,n_i,}{%
	res[i,l] = y[i,l] - beta'*x[i,l] - b[i]'*z[i,l], i=1,\dots,N,
	l=1,\dots,n[i],} where \eqn{y_{i,l}}{y[i,l]} is a (sampled)
        log-event time at each iteration.
    }
  }        
}
\references{
\eqn{\mbox{Kom\'arek}}{Komarek}, A., Lesaffre, E. (2004).
Bayesian Accelerated Failure Time Model for Correlated Censored Data
with a Normal Mixture as an Error Distribution.
\emph{In preparation, see /doc/KomarekLesaffre2004.pdf in this R package.}
  
Brooks, S. P., Giudici, P., and Roberts, G. O. (2003).
Efficient construction of reversible jump Markov chain Monte Carlo
proposal distribution (with Discussion).
\emph{Journal of the Royal Statistical Society B,} \bold{65,} 3 - 55.

Green, P. J. (1995).
Reversible jump MCMC computation and Bayesian model determination.
\emph{Biometrika,} \bold{82,} 711-732.

Richardson, S., and Green, P. J. (1997).
On Bayesian analysis of mixtures with unknown number of components (with
Discussion).
\emph{Journal of the Royal Statistical Society B,} \bold{59,} 731 - 792.

}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
  ## There are two vignettes with this package that describe analyses presented
  ## in Komarek and Lesaffre (2004). You should find them in /doc directory
  ## of this library (cgd1.Rnw, tandmob.Rnw are sources to create the vignettes).
  
  ## I hope they give enough material to understand how the package works.
}
\keyword{survival}
\keyword{regression}






\eof
\name{bayessurvreg1.files2init}
\alias{bayessurvreg1.files2init}
\title{
   Read the initial values for the Bayesian survival regression model to the list.
}
\description{
   This function creates the list of initial values as required by the \code{init}
   argument of the function \code{\link{bayessurvreg1}}. The initials are taken from
   the files that are of the form of the files where the simulated values from
   the McMC run performed by the function \code{\link{bayessurvreg1}} are stored.
   The files are assumed to have the following names: "iteration.sim",
   "mixmoment.sim", "mweight.sim", "mmean.sim", "mvariance.sim",   
   "beta.sim", "b.sim", "Y.sim", "r.sim", "D.sim", "otherp.sim", "u.sim". Some of these files
   may be missing. In that case, the corresponding initial is filled by \code{NULL}.
}
\usage{
bayessurvreg1.files2init(dir = getwd(), row, kmax)
}
\arguments{
  \item{dir}{string giving the directory where it will be searched for the files with 
    initial values.}
  \item{row}{the row (possible header does not count) from the files with the
    values that will be considered to give the initial values. By default,
    it is the last row from the files.}
  \item{kmax}{maximal number of mixture components. This must be given
    only if \code{header == FALSE}.}
}
\value{
  A list with components called "iter", "mixture", "beta", "b", "D", "y",
  "r", "otherp", "u"
  in the form as required by the argument \code{init} of the function \code{\link{bayessurvreg1}}.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{file}

\eof
\name{bayessurvreg1.help}
\alias{bayessurvreg1.help}
\alias{bayessurvreg1.checkStore}
\alias{bayessurvreg1.priorInit}
\alias{bayessurvreg1.revjump}
\alias{bayessurvreg1.writeHeaders}
\title{
   Helping function for Bayesian survival regression models, version 1.
}
\description{
  These functions are not to be called by ordinary users.

  These are just sub-parts of `bayessurvreg1' function to make it more
  readable for the programmer.
}
\usage{
bayessurvreg1.checkStore(store)

bayessurvreg1.priorInit(prior, init, Yinit, Xinit, n, nX, nrandom,
   ncluster, indb, randomInt, toler.chol)

bayessurvreg1.revjump(prop.revjump)

bayessurvreg1.writeHeaders(dir, prior, store, nX, X, names.random,
   ncluster, nrandom, rnamesX, unique.cluster, nBetaBlocks, nbBlocks)
}
\arguments{
  \item{store}{}
  \item{prior, init, Yinit, Xinit, n, nX, nrandom, ncluster}{}
  \item{indb, randomInt, toler.chol}{}
  \item{prop.revjump}{}
  \item{dir, X, names.random}{}
  \item{rnamesX, unique.cluster, nBetaBlocks, nbBlocks}{}
}
\value{
  Some lists.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{internal}
\keyword{connection}

\eof
\name{densplot2}
\alias{densplot2}
\title{
  Probability density function estimate from MCMC output
}
\description{
  Displays a plot of the density estimate for each variable in x, calculated by the density function. 

  This is slightly modified version of \code{\link[coda]{densplot}} function
  of a \code{coda} library to conform to my personal preferences.
}
\usage{
densplot2(x, plot = TRUE, show.obs = FALSE, bwf, bty = "n", main = "", xlim, ylim, xlab, ylab, \dots) 
}
\arguments{
  \item{x}{an \code{\link[coda]{mcmc}} or \code{\link[coda]{mcmc.list}} object.}
  \item{plot}{if \code{TRUE} this function works more or less in the
    same way as \code{coda} function \code{\link[coda]{densplot}} function.
    If \code{FALSE} this function returns one data frame for each chain
    with computed density which can be used for future plotting.}
  \item{show.obs}{show observations along the x-axis?}
  \item{bwf}{function for calculating the bandwidth. If omitted, the
    bandwidth is calculate by 1.06 times the minimum of the standard
    deviation and the interquartile range divided by 1.34 times the
    sample size to the negative one fifth power.}
  \item{xlim, ylim, xlab, ylab}{further arguments passed to the
    \code{\link{plot.default}} function.}  
  \item{bty, main, \dots}{further arguments passed to the
    \code{\link{plot.default}} function.}
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{hplot}

\eof
\name{files2coda}
\alias{files2coda}
\title{
   Read the sampled values from the Bayesian survival regression model
   to a coda mcmc object.
}
\description{
   This function creates a \code{coda} \code{mcmc} object from values found
   in files where sampled values from one of the functions from the
   family of \code{bayessurvreg} functions or from data.frames.
}
\usage{
files2coda(files, data.frames, variant = 1, dir = getwd(),
   start = 1, end, thin = 1, header = TRUE, chain)
}
\arguments{
  \item{files}{a vector of strings giving the names of files that are to
  be converted to \code{coda} objects. If missing and \code{data.frames}
  is also missing, all appropriate files
  found in a directory \code{dir} are converted to coda objects. File
  "iteration.sim" is always used (if found) to index the sampled
  values. If this file is not found the sampled values are indexed from
  1 to the sample size. If "mixture.sim" appeares here, only the column
  with number of mixture components is converted to the coda object.}
  \item{data.frames}{a vector of strings giving the names of data.frames
  that are to be converted to \code{coda} objects.
  }
  \item{variant}{a variant of \code{bayessurvreg} function used to
    generate sampled values. This argument is only used to identify
    appropriate files when \code{files} argument is missing.}
  \item{dir}{string giving the directory where it will be searched for the files with 
    sampled values.}
  \item{start}{the first row (possible header does not count) from the files with the
    sampled values that will be converted to coda objects.}
  \item{end}{the last row from the files with the sampled values that
    will be converted to coda objects. If missing, it is the last row in
    files.}
  \item{thin}{additional thinning of sampled values (i.e. only every
    \code{thin} value from \code{files} and \code{data.frames} is considered).}
  \item{header}{TRUE or FALSE indicating whether the files with the sampled values
    contain also the header on the first line or not.}
  \item{chain}{parameter giving the number of the chain if parallel
    chains were created and sampled values stored in data.frames further
    stored in lists(). If \code{missing}, data.frames are not assumed to
    be stored in lists.}
}
\value{
  A list with \code{mcmc} objects. One object per file or data.frame.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
## *** illustration of usage of parameters 'data.frames' and 'chain' ***
## *********************************************************************
## Two parallel chains with four variables, stored in data.frames
## data.frames are further stored in lists
library(coda)

group1 <- list();  group2 <- list();  group3 <- list()
    ## first chain of first two variables:
  group1[[1]] <- data.frame(var1 = rnorm(100, 0, 1), var2 = rnorm(100, 5, 4))
    ## second chain of first two variables:   
  group1[[2]] <- data.frame(var1 = rnorm(100, 0, 1), var2 = rnorm(100, 5, 4))
    ## first chain of the third variable:
  group2[[1]] <- data.frame(var3 = rgamma(100, 1, 1))
    ## second chain of the third variable:
  group2[[2]] <- data.frame(var3 = rgamma(100, 1, 1))
    ## first chain of the fourth variable:
  group3[[1]] <- data.frame(var4 = rbinom(100, 1, 0.4))
    ## second chain of the fourth variable:
  group3[[2]] <- data.frame(var4 = rbinom(100, 1, 0.4))  

  ## Create mcmc objects for each chain separately
mc.chain1 <- files2coda(data.frames = c("group1", "group2", "group3"), chain = 1)
mc.chain2 <- files2coda(data.frames = c("group1", "group2", "group3"), chain = 2)

  ## Create mcmc.list to represent two parallel chains
mc <- mcmc.list(mc.chain1, mc.chain2)
rm(mc.chain1, mc.chain2)


## *** illustration of usage of parameter 'data.frames' without 'chain' ***
## ************************************************************************
## Only one chain for four variables was sampled and stored in three data.frames
    ## chain of first two variables:
  group1 <- data.frame(var1 = rnorm(100, 0, 1), var2 = rnorm(100, 5, 4))
    ## chain of the third variable:  
  group2 <- data.frame(var3 = rgamma(100, 1, 1))
    ## chain of the fourth variable:
  group3 <- data.frame(var4 = rbinom(100, 1, 0.4))                        

  ## Create an mcmc object
mc <- files2coda(data.frames = c("group1", "group2", "group3"))
}
\keyword{connection}

\eof
\name{plot.bayesDensity}
\alias{plot.bayesDensity}
\title{
  Plot an object of class bayesDensity
}  
\description{
  This function plots an object created by \code{\link{bayesDensity}}.
}
\usage{
\method{plot}{bayesDensity}(x, k.cond, dim.plot = TRUE, over = TRUE,
   alegend = TRUE, standard = TRUE,
   type = "l", bty = "n",
   xlab = expression(epsilon), ylab = expression(f(epsilon)),
   lty, xlim, ylim, xleg, yleg, main, \dots)
}
\arguments{
  \item{x}{an object of class \code{bayesDensity}.}
  \item{k.cond}{a numerical vector giving the numbers of mixture components for which the conditional densities
     are to be plotted. 0 states for the unconditional (overall) density, averaged over the mixture with all possible
     numbers of components. If NULL, all conditional and the
     unconditional density found in \code{x} will be plotted.}
   \item{dim.plot}{an indicator whether the dimension of the plot used
     in \code{par(mfrow)} should be computed automatically. If
     \code{dim.plot = FALSE} and \code{over = FALSE} the user has to
     determine himself using \code{par(mfrow)} how to put the plots on
     the page.}
   \item{over}{an indicator whether all densities should be drawn into
     one plot using different types of lines. If \code{FALSE} a separate
     plot for each density is created.}
   \item{alegend}{an indicator whether an automatic legend should be
     added to the plot.}
   \item{standard}{logical, do we want to plot standardized or
     unstandardized density?}
   \item{xleg, yleg}{position of the legend if \code{over = TRUE}.}
   \item{type, bty, xlab, ylab, lty, xlim, ylim, main, \dots}{other
     arguments passed to the \code{plot.default} function.}
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{hplot}


\eof
\name{predictive}
\alias{predictive}
\alias{predictive.control}
\title{
  Compute predictive quantities based on a Bayesian survival regression model.
}
\description{
  This function runs additional McMC to compute predictive survivor and
  hazard curves and predictive event times for specified values of
  covariates.

  Firstly, the function \code{\link{bayessurvreg1}} has to be used to
  obtain a sample from the posterior distribution of unknown quantities.

  Directly, posterior predictive quantiles and means of asked quantities
  are computed and stored in files.
  
  Function \code{predictive.control} serves only to perform some input
  checks inside the main function \code{predictive}.
}
\usage{
predictive(
     formula,
     random,
     time0 = 0,
     data = parent.frame(),
     grid,
     type,
     subset,
     na.action = na.fail,
     quantile = c(0, 0.025, 0.5, 0.975, 1),                       
     nsimul = list(niter = 10, nwrite = 10),
     predict = list(Et=TRUE, t=FALSE, Surv=TRUE,
                    hazard=FALSE, cum.hazard=FALSE),
     store = list(Et=TRUE, t = FALSE, Surv = FALSE,
                  hazard = FALSE, cum.hazard=FALSE),
     Eb0.depend.mix = FALSE,
     dir = getwd(),
     toler.chol = 1e-10,
     toler.qr = 1e-10,
     \dots)

predictive.control(predict, store, quantile)
}
\arguments{
  \item{formula}{same formula as that one used to sample from the
    posterior distribution of unknown quantities by the function
    \code{\link{bayessurvreg1}}.}
  \item{random}{same \code{random} statement as that one used to sample from the
    posterior distribution of unknown quantities by the function
    \code{\link{bayessurvreg1}}.}
  \item{time0}{starting time for the survival model. This option is used
  to get correct hazard function in the case that the original model was
  \eqn{\log(T-time0) = \dots}{log(T - time0) = \dots}.}
  \item{data}{optional data frame in which to interpret the variables
    occuring in the formulas. Usually, you create a new
    \code{data.frame} similar to that one used to obtain a sample from
    the posterior distribution. In this new \code{data.frame}, put
    covariate values equal to these for which predictive quantities are
    to be obtained. If \code{cluster} statement was used, assign a
    unique cluster identification to each observation. Response variable
    and a censoring indicator may be set to arbitrary values. They are
    only used in \code{formula} but are ignored for computation.}
  \item{grid}{a list of length as number of observations in \code{data} or a vector
    giving grids of values where predictive survivor functions, hazards, cumulative
    hazards are to be evaluated. If it is a vector, same grid is used for all
    observations from \code{data}. Not needed if only \code{predict$t}
    or \code{predict$Et} are \code{TRUE}. If \code{time0} is different
    from zero your grid should start at \code{time0} and not at zero.}
  \item{type}{a character string giving the type of assumed error distribution. Currently, valid
    are substrings of "mixture". In the future, "spline",
    "polya.tree" might be also implemented.}
  \item{subset}{subset of the observations from the \code{data} to be
    used. This option will normally not be needed.}  
  \item{na.action}{function to be used to handle any \code{NA}s in the
    data. The user is discouraged to change a default value
    \code{na.fail}.}
  \item{quantile}{a vector of quantiles that are to be computed for each
    predictive quantity.}
  \item{nsimul}{a list giving the length of the simulation used to
    sample from posterior predictive distribution. It should be
    consistent with already simulated values obtained by
    \code{\link{bayessurvreg1}} function. The list has the following
    components.
    \describe{
      \item{niter}{number of iterations that are to be performed. It
	should not be higher than the number already simulated values.}
      \item{nwrite}{interval in which predictive quantities are written
	to files.}
    }      
  }
  \item{predict}{a list of logical values indicating which predictive quantities are to be sampled.
    Components of the list:
    \describe{
      \item{Et}{predictive expectations of survivor times}
      \item{t}{predictive survivor times}
      \item{Surv}{predictive survivor functions}
      \item{hazard}{predictive hazard functions}
      \item{cum.hazard}{predictive cumulative hazard functions}
    }
  }  
  \item{store}{a list of logical values indicating which predictive
    quantities are to be stored in files as `predET*.sim', `predT*.sim',
    `predS*.sim', `predhazard*.sim', `predcumhazard*.sim'. If you are
    interested only in posterior means or quantiles of the predictive
    quantities you do not have to store sampled values. Posterior means
    and quantiles are stored in files `quantET*.sim', `quantT*.sim',
    `quantS*.sim', `quanthazard*.sim', `quantpredhazard*.sim'.}
  \item{Eb0.depend.mix}{a logical value indicating whether the mean of
    the random intercept (if included in the model) was given in a
    hierarchical model as an overall mean of the mixture in the error
    term. With \code{FALSE} (default) you have the same model as that
    one described in an accompanying paper. An ordinary user is
    discouraged from setting this to \code{TRUE}.}
  \item{dir}{a string giving a directory where previously simulated
    values were stored and where newly obtained quantities will be
    stored. On Unix, do not use `~/' to specify your home directory.
    A full path must be given, e.g. `/home/arnost/'.}
  \item{toler.chol}{tolerance for the Cholesky decomposition.}
  \item{toler.qr}{tolerance for the QR decomposition.}  
  \item{\dots}{who knows?}
}
\value{
  An integer which should be equal to zero if everything ran fine.
}  
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
  ## See attached files.
}
\keyword{survival}
\keyword{regression}

\eof
\name{print.bayesDensity}
\alias{print.bayesDensity}
\title{
   Print a summary for the density estimate based on the Bayesian model.
}
\description{
   This function prints a~object created by \code{\link{bayesDensity}}.
}
\usage{
\method{print}{bayesDensity}(x, \dots)
}
\arguments{
  \item{x}{an object of class \code{bayesDensity}.}
  \item{\dots}{this is here for a consistency with a generic function.}  
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{print}


\eof
\name{sampleCovMat}
\alias{sampleCovMat}
\title{
   Compute a sample covariance matrix.
}
\description{
   This function computes a sample covariance matrix. 
}
\usage{
sampleCovMat(sample)
}
\arguments{
  \item{sample}{a \code{matrix} or \code{data.frame} with sampled values
    in rows. I.e. number of rows of \code{sample} determines a sample
    size, number of columns of \code{sample} determines a dimension of
    the distribution from which it was sampled.
  }     
}
\value{This function returns a matrix.
}
\details{
  When \eqn{y_1, \dots, y_n}{y[1], ..., y[n]} is a sequence of
  \eqn{p}{p}-dimensional vectors \eqn{y_i}{y[i]} the sample covariance
  matrix \eqn{S}{S} is equal to
  \deqn{S = \frac{1}{n-1} \sum_{i=1}^n (y_i - m)(y_i - m)^T}{%
        S = (1/(n-1)) sum[i=1][n] (y[i] - m)(y[i] - m)'}
      where \deqn{m = \frac{1}{n}\sum_{i=1}^n y_i.}{%
	          m = (1/n) sum[i=1][n] y[i].}
  When \eqn{n=1}{n=1} the function returns just sum of squares.      
}  
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
  ## Sample some values
  z1 <- rnorm(100, 0, 1)           ## first components of y
  z2 <- rnorm(100, 5, 2)           ## second components of y
  z3 <- rnorm(100, 10, 0.5)        ## third components of y

  ## Put them into a data.frame
  sample <- data.frame(z1, z2, z3)

  ## Compute a sample covariance matrix
  sampleCovMat(sample)
}
\keyword{multivariate}

\eof
\name{traceplot2}
\alias{traceplot2}
\title{
  Trace plot of McMC output.
}
\description{  
  Displays a plot of iterations vs. sampled values for each variable in
  the chain, with a separate plot per variable.

  This is slightly modified version of \code{\link[coda]{traceplot}} function
  of a \code{coda} library to conform to my personal preferences.
}
\usage{
traceplot2(x, chains, bty = "n", main, xlab, ...)
}
\arguments{
  \item{x}{an \code{\link[coda]{mcmc}} or \code{\link[coda]{mcmc.list}} object.}
  \item{chains}{indeces of chains from the object that are to be plotted.}
  \item{bty, main, xlab, \dots}{further arguments passed to the
    \code{\link{plot.default}} function.}
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{hplot}

\eof
